==> n_rebuild-5.x-1.23.tar.gz: n_rebuild/page.tpl.php <==
<?php

/**
 * ------------------------
 * [RU]  .
 * ------------------------
 */

?><<?php print '?'; ?>xml version="1.0"<?php print '?'; ?>>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language; ?>" lang="<?php print $language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?>
<?php print rewrite_styles(); ?>
<!--[if lt IE 7]><style type="text/css" media="all">@import "<?php print $full_theme_path; ?>nx-style-ltIE7.css.php";</style><![endif]-->
<?php print $scripts; ?>
<script type="text/javascript">
<!--//--><![CDATA[//><!--
    nx_base_path = '<?php print $base_path; ?>';
//--><!]]>
</script>
</head>

<?php
	if ($site_name) {$site_name = check_plain($site_name);}
	if ($site_slogan) {$site_slogan = check_plain($site_slogan);}
	$site_title = $site_name ? $site_name : t('Home');
 ?>

<body class="<?php print $nx_body_classes; ?>">

<br />

<table class="page_struct struct">
    <tr><td class="struct">&nbsp;</td>
	<td class="page_struct-page-acceptor struct">

	<div class="page">

	    <table class="page_part before_head_part struct">
		<tr>
		    <td class="column_1 struct visible_struct">
			<div class="region_description">before head &gt; column 1</div>
		        <div class="column_1-content_cover">
			    <?php print $before_head_column_1_region; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_2 struct visible_struct">
			<div class="region_description">before head &gt; column 2</div>
		        <div class="column_2-content_cover">
			    <?php print $before_head_column_2_region; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_3 struct visible_struct">
			<div class="region_description">before head &gt; column 3</div>
			<div class="column_3-content_cover">
			    <?php print $before_head_column_3_region; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>


	<div class="page_part_bounder">&nbsp;</div>

	
	    <table class="page_part head_part struct">
		<tr>
		    <td class="column_1 struct visible_struct">
			<a class="logo ff_clear_link" href="<?php print check_url($base_path); ?>" title="<?php print $site_title; ?>">
			    <img src="<?php print check_url($logo); ?>" alt="<?php print $site_title; ?>" />
			</a>
		    </td>
		    <td class="column_2 struct visible_struct">
			<div class="region_description">head &gt; column 2</div>
			<div class="column_2-content_cover">
			    <?php print $header; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_3 struct visible_struct">
			<div class="region_description">head &gt; column 3</div>
			<div class="column_3-content_cover">
			    <?php print $head_column_3_region; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>


	<div class="page_part_bounder">&nbsp;</div>


	    <table class="page_part body_part struct">
		<tr>
		    <td class="column_1 struct visible_struct">
			<div class="region_description">body &gt; column 1</div>
			<div class="column_1-content_cover">
			<!-- ================================================== -->
			<!-- == left sidebar ================================== -->
			<!-- ================================================== -->
			    <?php if ($sidebar_left): ?>
				<?php print $sidebar_left; ?>
			    <?php endif; ?>
			<!-- ================================================== -->
			<!-- ================================================== -->
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_2 struct visible_struct">
			<div class="region_description">body &gt; column 2</div>
			<div class="column_2-content_cover">
			<!-- ================================================== -->
			<!-- == content ======================================= -->
			<!-- ================================================== -->
			    <?php if ($breadcrumb) {print $breadcrumb;} ?>
			    <?php if ($title): print '<h2 class="c_page_title">'. $title .'</h2><div class="c_clear">&nbsp;</div>'; endif; ?>
			    <?php if($tabs_pri || $tabs_sec) : ?>
				<div class="all_tabs">
				    <?php print $tabs_pri; ?>
					<div class="tabs_bounder"></div>
				    <?php print $tabs_sec; ?>
				</div>
			    <?php endif; ?>
			    <?php print $messages; ?>
			    <?php print $help; ?>
			    <?php print $content; ?>
			<!-- ================================================== -->
			<!-- ================================================== -->
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_3 struct visible_struct <?php print (!$right?'body-column_3-invisible':''); ?>">
			<div class="region_description">body &gt; column 3</div>
			<div class="column_3-content_cover">
			<!-- ================================================== -->
			<!-- == right sidebar ================================== -->
			<!-- ================================================== -->
			    <?php if ($sidebar_right): ?>
				<?php print $sidebar_right; ?>
			    <?php endif; ?>
			<!-- ================================================== -->
			<!-- ================================================== -->
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>


	<div class="page_part_bounder">&nbsp;</div>


	    <table class="page_part foot_part struct">
		<tr>
		    <td class="column_1 struct visible_struct">
			<div class="region_description">foot &gt; column 1</div>
			<div class="column_1-content_cover">
			    <?php print $foot_column_1_region; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_2 struct visible_struct">
			<div class="region_description">foot &gt; column 2</div>
		    	<div class="column_2-content_cover">
			    <?php print $footer_region; ?>
			    <?php if (strlen($footer_message) > 1) : ?>
				<div class="footer_message">
				    <?php print $footer_message; ?>
				</div>
			    <?php endif; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_3 struct visible_struct">
			<div class="region_description">foot &gt; column 3</div>
		    	<div class="column_3-content_cover">
			    <?php print $foot_column_3_region; ?>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>

	</div>

	</td><td class="struct">&nbsp;</td></tr>
</table>
<br />
<div class="techno_bottom_region">
    <center><?php print $techno_bottom_region; ?></center>
</div>
<br />
<br />


<?php global $user; if ($user->uid == 0) : ?>
<div class="preLoad">
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-LC-collapsed-BG.png)">&nbsp;</div>
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-LC-expanded-BG.png)">&nbsp;</div>
</div>
<?php endif; ?>

<?php /* if ($mission): print '<div id="mission">'. $mission .'</div>'; endif; */ ?>
<?php /* if ($site_slogan): print '<div id="site_slogan">'. $site_slogan .'</div>'; endif; */ ?>
<?php /* if (isset($primary_links)): print theme('links', $primary_links, array('class' => 'primary_links'), array('outer_prefix' => '', 'inner_prefix' => '<span><span>', 'inner_suffix' => '</span></span>', 'outer_suffix' => '')); endif; */ ?>
<?php /* if (isset($secondary_links)): print theme('links', $secondary_links, array('class' => 'secondary_links'), array('outer_prefix' => '', 'inner_prefix' => '<span><span>', 'inner_suffix' => '</span></span>', 'outer_suffix' => '')); endif; */ ?>
<?php print $closure; ?>
</body>
</html>

==> n_rebuild-5.x-1.30.tar.gz: n_rebuild/page.tpl.php <==
<?php

/**
 * ------------------------
 * [RU]  .
 * ------------------------
 */

?><<?php print '?'; ?>xml version="1.0"<?php print '?'; ?>>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language; ?>" lang="<?php print $language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?>
<?php print rewrite_styles(); ?>
<!--[if lt IE 8]><style type="text/css" media="all">@import "<?php print $full_theme_path; ?>nx-style-ltIE8.css";</style><![endif]-->
<!--[if lt IE 7]><style type="text/css" media="all">@import "<?php print $full_theme_path; ?>png_fix.css.php";</style><![endif]-->
<?php print $scripts; ?>
<script type="text/javascript">
<!--//--><![CDATA[//><!--
    nx_base_path = '<?php print $base_path; ?>';
//--><!]]>
</script>
</head>

<?php
	if ($site_name) {$site_name = check_plain($site_name);}
	if ($site_slogan) {$site_slogan = check_plain($site_slogan);}
	$site_title = $site_name ? $site_name : t('Home');
 ?>

<body class="<?php print $nx_body_classes; ?>">

<br />

<table class="page_struct struct">
    <tr><td class="struct">&nbsp;</td>
	<td class="page_struct-page-acceptor struct">

	<div class="page">

	    <table class="page_part before_head_part struct">
		<tr>
		    <td class="column_1 struct">
			<div class="region_description">before head &gt; column 1</div>
		        <div class="column_1-content_cover-1">
			<div class="column_1-content_cover-2">
			    <?php print $before_head_column_1_region; ?>
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_2 struct">
			<div class="region_description">before head &gt; column 2</div>
		        <div class="column_2-content_cover-1">
			<div class="column_2-content_cover-2">
			    <?php print $before_head_column_2_region; ?>
			</div>
			</div>
		    </td>
		    <td class="column_3 struct">
			<div class="region_description">before head &gt; column 3</div>
			<div class="column_3-content_cover-1">
			<div class="column_3-content_cover-2">
			    <?php print $before_head_column_3_region; ?>
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>


	    <table class="page_part head_part struct">
		<tr>
		    <td class="column_1 struct">
			<div class="region_description">logo [not region]</div>
			<a class="logo ff_clear_link" href="<?php print check_url($base_path); ?>" title="<?php print $site_title; ?>">
			    <img src="<?php print check_url($logo); ?>" alt="<?php print $site_title; ?>" />
			</a>
		    </td>
		    <td class="column_2 struct">
			<div class="region_description">head &gt; column 2</div>
			<div class="column_2-content_cover-1">
			<div class="column_2-content_cover-2">
			    <?php print $header; ?>
			</div>
			</div>
		    </td>
		    <td class="column_3 struct">
			<div class="region_description">head &gt; column 3</div>
			<div class="column_3-content_cover-1">
			<div class="column_3-content_cover-2">
			    <?php print $head_column_3_region; ?>
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>


	    <table class="page_part body_part struct">
		<tr>
		    <td class="column_1 struct">
			<div class="region_description">body &gt; column 1</div>
			<div class="column_1-content_cover-1">
			<div class="column_1-content_cover-2">
			<!-- ================================================== -->
			<!-- == left sidebar ================================== -->
			<!-- ================================================== -->
			    <?php if ($sidebar_left): ?>
				<?php print $sidebar_left; ?>
			    <?php endif; ?>
			<!-- ================================================== -->
			<!-- ================================================== -->
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_2 struct">
			<div class="region_description">body &gt; column 2</div>
			<div class="column_2-content_cover-1">
			<div class="column_2-content_cover-2">
			<!-- ================================================== -->
			<!-- == content ======================================= -->
			<!-- ================================================== -->
			    <?php if ($breadcrumb) {print $breadcrumb;} ?>
			    <?php if ($title): print '<h2 class="c_page_title">'. $title .'</h2><div class="c_clear">&nbsp;</div>'; endif; ?>
			    <?php if($tabs_pri || $tabs_sec) : ?>
				<div class="all_tabs">
				    <?php print $tabs_pri; ?>
					<div class="tabs_bounder"></div>
				    <?php print $tabs_sec; ?>
				</div>
			    <?php endif; ?>
			    <?php print $messages; ?>
			    <?php print $help; ?>
			    <?php print $content; ?>
			<!-- ================================================== -->
			<!-- ================================================== -->
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_3 struct <?php print (!$right?'body-column_3-invisible':''); ?>">
			<div class="region_description">body &gt; column 3</div>
			<div class="column_3-content_cover-1">
			<div class="column_3-content_cover-2">
			<!-- ================================================== -->
			<!-- == right sidebar ================================== -->
			<!-- ================================================== -->
			    <?php if ($sidebar_right): ?>
				<?php print $sidebar_right; ?>
			    <?php endif; ?>
			<!-- ================================================== -->
			<!-- ================================================== -->
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>


	    <table class="page_part foot_part struct">
		<tr>
		    <td class="column_1 struct">
			<div class="region_description">foot &gt; column 1</div>
			<div class="column_1-content_cover-1">
			<div class="column_1-content_cover-2">
			    <?php print $foot_column_1_region; ?>
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		    <td class="column_2 struct">
			<div class="region_description">foot &gt; column 2</div>
		    	<div class="column_2-content_cover-1">
			<div class="column_2-content_cover-2">
			    <?php print $footer_region; ?>
			    <?php if (strlen($footer_message) > 1) : ?>
				<div class="footer_message">
				    <?php print $footer_message; ?>
				</div>
			    <?php endif; ?>
			</div>
			</div>
		    </td>
		    <td class="column_3 struct">
			<div class="region_description">foot &gt; column 3</div>
		    	<div class="column_3-content_cover-1">
			<div class="column_3-content_cover-2">
			    <?php print $foot_column_3_region; ?>
			</div>
			</div>
			<img class="min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
		    </td>
		</tr>
	    </table>

	</div>

	</td><td class="struct">&nbsp;</td></tr>
</table>
<br />
<div class="techno_bottom_region">
    <center><?php print $techno_bottom_region; ?></center>
</div>
<br />
<br />


<?php global $user; if ($user->uid == 0) : ?>
<div class="preLoad">
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-LC-collapsed-BG.png)">&nbsp;</div>
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-LC-expanded-BG.png)">&nbsp;</div>
</div>
<?php endif; ?>

<?php /* if ($mission): print '<div id="mission">'. $mission .'</div>'; endif; */ ?>
<?php /* if ($site_slogan): print '<div id="site_slogan">'. $site_slogan .'</div>'; endif; */ ?>
<?php /* if (isset($primary_links)): print theme('links', $primary_links, array('class' => 'primary_links'), array('outer_prefix' => '', 'inner_prefix' => '<span><span>', 'inner_suffix' => '</span></span>', 'outer_suffix' => '')); endif; */ ?>
<?php /* if (isset($secondary_links)): print theme('links', $secondary_links, array('class' => 'secondary_links'), array('outer_prefix' => '', 'inner_prefix' => '<span><span>', 'inner_suffix' => '</span></span>', 'outer_suffix' => '')); endif; */ ?>
<?php print $closure; ?>
</body>
</html>
